"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _react = require("@testing-library/react");
var _userEvent = _interopRequireDefault(require("@testing-library/user-event"));
var _vitest = require("vitest");
var _runAxeCheck = require("@instructure/ui-axe-check/lib/runAxeCheck.js");
require("@testing-library/jest-dom");
var _index = require("../index");
var _NumberInput5 = _interopRequireDefault(require("../__examples__/NumberInput.examples"));
var _generateA11yTests = require("@instructure/ui-scripts/lib/test/generateA11yTests");
var _IconZoomInLine2 = require("@instructure/ui-icons/lib/IconZoomInLine.js");
var _IconZoomOutLine2 = require("@instructure/ui-icons/lib/IconZoomOutLine.js");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _NumberInput, _NumberInput2, _NumberInput3, _NumberInput4, _IconZoomInLine, _IconZoomOutLine;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
// eslint-disable-next-line no-restricted-imports
describe('<NumberInput />', () => {
  let consoleWarningMock;
  let consoleErrorMock;
  beforeEach(() => {
    // Mocking console to prevent test output pollution
    consoleWarningMock = _vitest.vi.spyOn(console, 'warn').mockImplementation(() => {});
    consoleErrorMock = _vitest.vi.spyOn(console, 'error').mockImplementation(() => {});
  });
  afterEach(() => {
    consoleWarningMock.mockRestore();
    consoleErrorMock.mockRestore();
  });
  it('sets value on the input', async () => {
    const onChange = _vitest.vi.fn();
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.NumberInput, {
      renderLabel: "Label",
      onChange: onChange,
      value: "42"
    }));
    const input = _react.screen.getByRole('spinbutton');
    expect(input).toHaveValue(42);
  });
  it('should accept a number for the value', async () => {
    const onChange = _vitest.vi.fn();
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.NumberInput, {
      renderLabel: "Label",
      onChange: onChange,
      value: 42
    }));
    const input = _react.screen.getByRole('spinbutton');
    expect(input).toHaveValue(42);
  });
  it('displays the label', async () => {
    const _render = (0, _react.render)(_NumberInput || (_NumberInput = (0, _jsxRuntime.jsx)(_index.NumberInput, {
        renderLabel: "Label"
      }))),
      container = _render.container;
    const label = container.querySelector('span[class$="-formFieldLayout__label"]');
    expect(label).toHaveTextContent('Label');
  });
  it('passes the input element to inputRef', async () => {
    const inputRef = _vitest.vi.fn();
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.NumberInput, {
      renderLabel: "Label",
      inputRef: inputRef
    }));
    const input = _react.screen.getByRole('spinbutton');
    expect(inputRef).toHaveBeenCalledTimes(1);
    expect(inputRef).toHaveBeenCalledWith(input);
  });
  it('passes change events to onChange handler', async () => {
    const onChange = _vitest.vi.fn();
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.NumberInput, {
      renderLabel: "Label",
      onChange: onChange
    }));
    const input = _react.screen.getByRole('spinbutton');
    _userEvent.default.type(input, '5');
    await (0, _react.waitFor)(() => {
      const event = onChange.mock.calls[0][0];
      const args = onChange.mock.calls[0][1];
      expect(onChange).toHaveBeenCalledTimes(1);
      expect(args).toBe('5');
      expect(event.target.value).toBe('5');
    });
  });
  it('passes keyboard events to the onKeyDown handler', async () => {
    const onKeyDown = _vitest.vi.fn();
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.NumberInput, {
      renderLabel: "Label",
      onKeyDown: onKeyDown
    }));
    const input = _react.screen.getByRole('spinbutton');
    _userEvent.default.type(input, '5');
    await (0, _react.waitFor)(() => {
      expect(onKeyDown).toHaveBeenCalledTimes(1);
    });
  });
  it('passes blur events to onBlur handler', async () => {
    const onBlur = _vitest.vi.fn();
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.NumberInput, {
      renderLabel: "Label",
      onBlur: onBlur
    }));
    _userEvent.default.tab();
    _userEvent.default.tab();
    await (0, _react.waitFor)(() => {
      expect(onBlur).toHaveBeenCalledTimes(1);
    });
  });
  it('passes focus events to onFocus handler', async () => {
    const onFocus = _vitest.vi.fn();
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.NumberInput, {
      renderLabel: "Label",
      onFocus: onFocus
    }));
    const input = _react.screen.getByRole('spinbutton');
    input.focus();
    await (0, _react.waitFor)(() => {
      expect(onFocus).toHaveBeenCalledTimes(1);
    });
  });
  it('shows arrow spinbuttons by default', async () => {
    const _render2 = (0, _react.render)(_NumberInput2 || (_NumberInput2 = (0, _jsxRuntime.jsx)(_index.NumberInput, {
        renderLabel: "Label"
      }))),
      container = _render2.container;
    const buttons = container.querySelectorAll('button[class$="-numberInput_arrow');
    expect(buttons).toHaveLength(2);
  });
  it('hides arrow spinbuttons when showArrows is false', async () => {
    const _render3 = (0, _react.render)(_NumberInput3 || (_NumberInput3 = (0, _jsxRuntime.jsx)(_index.NumberInput, {
        renderLabel: "Label",
        showArrows: false
      }))),
      container = _render3.container;
    const buttons = container.querySelectorAll('button[class$="-numberInput_arrow');
    expect(buttons).toHaveLength(0);
  });
  it('calls onIncrement when up arrow spinbutton is clicked', async () => {
    const onIncrement = _vitest.vi.fn();
    const _render4 = (0, _react.render)((0, _jsxRuntime.jsx)(_index.NumberInput, {
        renderLabel: "Label",
        onIncrement: onIncrement
      })),
      container = _render4.container;
    const buttons = container.querySelectorAll('button[class$="-numberInput_arrow');
    _userEvent.default.click(buttons[0]);
    await (0, _react.waitFor)(() => {
      expect(onIncrement).toHaveBeenCalledTimes(1);
    });
  });
  it('does not call onIncrement when `interaction` is set to readonly', async () => {
    const onIncrement = _vitest.vi.fn();
    const _render5 = (0, _react.render)((0, _jsxRuntime.jsx)(_index.NumberInput, {
        renderLabel: "Label",
        interaction: "readonly",
        onIncrement: onIncrement
      })),
      container = _render5.container;
    const buttons = container.querySelectorAll('button[class$="-numberInput_arrow');
    _userEvent.default.click(buttons[0]);
    await (0, _react.waitFor)(() => {
      expect(onIncrement).toHaveBeenCalledTimes(0);
    });
  });
  it('does not call onIncrement when `readOnly` is set', async () => {
    const onIncrement = _vitest.vi.fn();
    const _render6 = (0, _react.render)((0, _jsxRuntime.jsx)(_index.NumberInput, {
        renderLabel: "Label",
        readOnly: true,
        onIncrement: onIncrement
      })),
      container = _render6.container;
    const buttons = container.querySelectorAll('button[class$="-numberInput_arrow');
    _userEvent.default.click(buttons[0]);
    await (0, _react.waitFor)(() => {
      expect(onIncrement).toHaveBeenCalledTimes(0);
    });
  });
  it('calls onDecrement when down arrow spinbutton is clicked', async () => {
    const onDecrement = _vitest.vi.fn();
    const _render7 = (0, _react.render)((0, _jsxRuntime.jsx)(_index.NumberInput, {
        renderLabel: "Label",
        onDecrement: onDecrement
      })),
      container = _render7.container;
    const buttons = container.querySelectorAll('button[class$="-numberInput_arrow');
    _userEvent.default.click(buttons[1]);
    await (0, _react.waitFor)(() => {
      expect(onDecrement).toHaveBeenCalledTimes(1);
    });
  });
  it('does not call onDecrement when `interaction` is set to readonly', async () => {
    const onDecrement = _vitest.vi.fn();
    const _render8 = (0, _react.render)((0, _jsxRuntime.jsx)(_index.NumberInput, {
        renderLabel: "Label",
        interaction: "readonly",
        onDecrement: onDecrement
      })),
      container = _render8.container;
    const buttons = container.querySelectorAll('button[class$="-numberInput_arrow');
    _userEvent.default.click(buttons[1]);
    await (0, _react.waitFor)(() => {
      expect(onDecrement).toHaveBeenCalledTimes(0);
    });
  });
  it('does not call onDecrement when `readOnly` is set', async () => {
    const onDecrement = _vitest.vi.fn();
    const _render9 = (0, _react.render)((0, _jsxRuntime.jsx)(_index.NumberInput, {
        renderLabel: "Label",
        readOnly: true,
        onDecrement: onDecrement
      })),
      container = _render9.container;
    const buttons = container.querySelectorAll('button[class$="-numberInput_arrow');
    _userEvent.default.click(buttons[1]);
    await (0, _react.waitFor)(() => {
      expect(onDecrement).toHaveBeenCalledTimes(0);
    });
  });
  it('puts inputMode prop to input', async () => {
    (0, _react.render)(_NumberInput4 || (_NumberInput4 = (0, _jsxRuntime.jsx)(_index.NumberInput, {
      renderLabel: "Label",
      inputMode: "decimal"
    })));
    const input = _react.screen.getByRole('spinbutton');
    expect(input).toHaveAttribute('inputMode', 'decimal');
  });
  describe('with generated examples', () => {
    const generatedComponents = (0, _generateA11yTests.generateA11yTests)(_index.NumberInput, _NumberInput5.default);
    for (const component of generatedComponents) {
      it(component.description, async () => {
        const _render10 = (0, _react.render)(component.content),
          container = _render10.container;
        const axeCheck = await (0, _runAxeCheck.runAxeCheck)(container);
        expect(axeCheck).toBe(true);
      });
    }
  });
  it('renders custom interactive icons', async () => {
    const onDecrement = _vitest.vi.fn();
    const onIncrement = _vitest.vi.fn();
    const _render11 = (0, _react.render)((0, _jsxRuntime.jsx)(_index.NumberInput, {
        renderLabel: "Label",
        onIncrement: onIncrement,
        onDecrement: onDecrement,
        renderIcons: {
          increase: _IconZoomInLine || (_IconZoomInLine = (0, _jsxRuntime.jsx)(_IconZoomInLine2.IconZoomInLine, {})),
          decrease: _IconZoomOutLine || (_IconZoomOutLine = (0, _jsxRuntime.jsx)(_IconZoomOutLine2.IconZoomOutLine, {}))
        }
      })),
      container = _render11.container;
    const zoomInIcon = container.querySelector('svg[name="IconZoomIn"]');
    const zoomOutIcon = container.querySelector('svg[name="IconZoomOut"]');
    expect(zoomInIcon).toBeInTheDocument();
    expect(zoomOutIcon).toBeInTheDocument();
    const buttons = container.querySelectorAll('button[class$="-numberInput_arrow');
    _userEvent.default.click(buttons[0]);
    await (0, _react.waitFor)(() => {
      expect(onIncrement).toHaveBeenCalledTimes(1);
    });
    _userEvent.default.click(buttons[1]);
    await (0, _react.waitFor)(() => {
      expect(onDecrement).toHaveBeenCalledTimes(1);
    });
  });
});